aboutsummaryrefslogtreecommitdiff
path: root/src/geometry/contact_pair.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/geometry/contact_pair.rs')
-rw-r--r--src/geometry/contact_pair.rs11
1 files changed, 9 insertions, 2 deletions
diff --git a/src/geometry/contact_pair.rs b/src/geometry/contact_pair.rs
index 11e0188..50094ca 100644
--- a/src/geometry/contact_pair.rs
+++ b/src/geometry/contact_pair.rs
@@ -16,6 +16,12 @@ bitflags::bitflags! {
}
}
+impl Default for SolverFlags {
+ fn default() -> Self {
+ SolverFlags::COMPUTE_IMPULSES
+ }
+}
+
#[derive(Copy, Clone, Debug)]
#[cfg_attr(feature = "serde-serialize", derive(Serialize, Deserialize))]
/// A single contact between two collider.
@@ -126,10 +132,11 @@ pub struct SolverContact {
pub friction: Real,
/// The effective restitution coefficient at this contact point.
pub restitution: Real,
/// The artificially add relative velocity at the contact point.
/// This is set to zero by default. Set to a non-zero value to
/// simulate, e.g., conveyor belts.
- pub surface_velocity: Vector<Real>,
+ pub tangent_velocity: Vector<Real>,
/// Associated contact data used to warm-start the constraints
/// solver.
pub data: ContactData,
@@ -126,10 +132,11 @@ pub struct SolverContact {
/// The effective restitution coefficient at this contact point.
pub restitution: Real,
- /// The artificially add relative velocity at the contact point.
+ /// The desired tangent relative velocity at the contact point.
+ ///
/// This is set to zero by default. Set to a non-zero value to
/// simulate, e.g., conveyor belts.